=============================
django-templation
=============================

.. image:: https://badge.fury.io/py/django-templation.png
    :target: http://badge.fury.io/py/django-templation

.. image:: https://travis-ci.org/qdqmedia/django-templation.png?branch=master
    :target: https://travis-ci.org/qdqmedia/django-templation

.. image:: https://coveralls.io/repos/qdqmedia/django-templation/badge.png?branch=master
    :target: https://coveralls.io/r/qdqmedia/django-templation?branch=master

.. image:: https://pypip.in/d/django-templation/badge.png
    :target: https://crate.io/packages/django-templation?version=latest

.. image:: https://d2weczhvl823v0.cloudfront.net/qdqmedia/django-templation/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free

The easy way to allow designers edit templates and assets.

.. image :: https://raw.github.com/qdqmedia/django-templation/master/assets/workflow.png

Documentation
-------------

The full documentation is at http://django-templation.rtfd.org.


Installation
------------

Install django-templation::

    pip install django-templation


Features
--------

* Resource Access administration via Django admin.
* WebDAV access for designers to easily edit templates and static files from anywhere.
* Sandboxed templates: restrict the use of Django builtin template tags and filters

